#
# Author:: Adam Jacob (<adam@chef.io>)
# Copyright:: Copyright 2008-2016, Chef Software Inc.
# License:: Apache License, Version 2.0
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

require "chef/mixin/from_file"
require "chef/resource_definition"

class Chef
  class ResourceDefinitionList
    include Chef::Mixin::FromFile

    attr_accessor :defines

    def initialize
      @defines = Hash.new
    end

    def define(resource_name, prototype_params = nil, &block)
      @defines[resource_name] = ResourceDefinition.new
      @defines[resource_name].define(resource_name, prototype_params, &block)
      true
    end
  end
end
